#!/bin/sh -
#
# chkconfig: 2345 95 5
# SGL-START:1 2 3 5:S95
# SGL-STOP:0 6:K05
# description: OpenMosix configures your computer to be part
#              of a high-performance computing cluster on your system.
#
# openmosix    Script to enable/disable openmosix on your system.
#
## Copyright (c) 2002 Amit Shah (amitshah@gmx.net)
##
## Mosix is (c) of prof. Barak http://www.mosix.org
## OpenMosix is (c) of Moshe Bar http://www.openmosix.com
## Each respective trademark is of its own owner
## All rights reserved.
##
## This software is distributed under GPL 2
## THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTY IS ASSUMED.
## NO LIABILITY OF ANY KIND FOR ANY DAMAGES WHATSOEVER RESULTING
## FROM THE USE OF THIS SOFTWARE WILL BE ACCEPTED. IT CAN BURN
## YOUR HARD DISK, ERASE ALL YOUR DATA AND BREAK DOWN YOUR
## MICROWAVE OVEN. YOU ARE ADVISED.

#daemon openmosix

. /etc/init.d/functions

disable_openmosix() {
        # is this an openmosix system?
        if [ -f /proc/hpc/admin/mospe ]
	then
	    echo 0 > /proc/hpc/admin/mospe
	else
	    echo "This is not OpenMosix!"
            exit 1
	fi

	echo "Disabling OpenMosix..."
        rm -f /var/lock/openmosix
}

enable_openmosix() {

        # check if openmosix is already enabled
        if [ -f /var/lock/openmosix ]
	then
	    echo OpenMosix already enabled.
	    exit 2 # error condition
	fi

        # read the configuration in /etc/openmosix.map in the kernel
        # via the /proc/hpc interface.
	if [ -f /etc/openmosix.map ]; then
	    echo "Initializing OpenMosix..." 
            /sbin/setpe -W $a1 $a2 -f /etc/openmosix.map
	fi

        # for us to know that we're running...
	if [ $? -eq 0 ] # if the command above was successful
	then
	    touch /var/lock/openmosix
	fi
}

# Control is given here when the script is run.
case "$1" in
  start) # Attempt to enable openmosix on this node

	#echo "Initializing OpenMOSIX..."
	if [ ! -f /etc/openmosix.map ]
	then
 	# map doesn't exist -- display warning message
	    echo "Please configure the openmosix.map file in /etc."
	    echo "For instructions, refer the README that came"
	    echo "along with the openMosix userland tools."
	    exit 1;
	fi
		
	enable_openmosix ;;

  stop) # Disable openmosix for this session

	#echo "Disabling OpenMOSIX..."
	disable_openmosix ;;

  status) # what's our current status: enabled/disabled?

	/sbin/setpe -r ;;

  restart|reload) # disable, then re-enable openmosix on this node.

	echo "Restarting OpenMOSIX..."
	disable_openmosix
	enable_openmosix ;;

  *) # if no command-line arguments given or invalid argument:

	echo "Usage: openmosix {start|stop|status|restart|reload}"
	exit 1 # error condition
esac

exit 0 # successful termination... ie no error.
